@@ -55,6 +55,7 @@ class KNewFileMenu;
 
 namespace KIO {
     class DropJob;
+    class StatJob;
 }
 
 class ScreenMapper;
@@ -315,6 +316,7 @@ class FOLDERPLUGIN_TESTS_EXPORT FolderModel : public QSortFilterProxyModel, publ
         KDirWatch *m_dirWatch;
         QString m_url;
         QHash<QUrl, bool> m_isDirCache;
+        mutable QHash<QUrl, KIO::StatJob *> m_isDirJobs;
         QItemSelectionModel *m_selectionModel;
         QItemSelection m_pinnedSelection;
         QModelIndexList m_dragIndexes;
@@ -341,7 +343,11 @@ class FOLDERPLUGIN_TESTS_EXPORT FolderModel : public QSortFilterProxyModel, publ
         bool m_sortDirsFirst;
         bool m_parseDesktopFiles;
         bool m_previews;
+        // An empty previewPlugin list means use default.
+        // We don't want to leak that fact to the QML side, however, so the property stays empty
+        // and internally we operate on effectivePreviewPlugins instead.
         QStringList m_previewPlugins;
+        QStringList m_effectivePreviewPlugins;
         FilterMode m_filterMode;
         QString m_filterPattern;
         bool m_filterPatternMatchAll;
