@@ -94,6 +94,9 @@ ViewPropertiesMenu::ViewPropertiesMenu(QObject *parent) : QObject(parent)
         m_iconSize->addAction(action);
     }
 
+    m_previews = m_menu->addAction(QIcon::fromTheme(QStringLiteral("view-preview")), i18n("Show Previews"), this, &ViewPropertiesMenu::previewsChanged);
+    m_previews->setCheckable(true);
+
     m_locked = m_menu->addAction(i18n("Locked"), this, SIGNAL(lockedChanged()));
     m_locked->setCheckable(true);
 }
@@ -186,6 +189,18 @@ void ViewPropertiesMenu::setAlignment(int alignment)
     }
 }
 
+bool ViewPropertiesMenu::previews() const
+{
+    return m_previews->isChecked();
+}
+
+void ViewPropertiesMenu::setPreviews(bool previews)
+{
+    if (m_previews->isChecked() != previews) {
+        m_previews->setChecked(previews);
+    }
+}
+
 bool ViewPropertiesMenu::locked() const
 {
     return m_locked->isChecked();
@@ -198,6 +213,19 @@ void ViewPropertiesMenu::setLocked(bool locked)
     }
 }
 
+bool ViewPropertiesMenu::lockedEnabled() const
+{
+    return m_locked->isEnabled();
+}
+
+void ViewPropertiesMenu::setLockedEnabled(bool enabled)
+{
+    if (m_locked->isEnabled() != enabled) {
+        m_locked->setEnabled(enabled);
+        emit lockedEnabledChanged();
+    }
+}
+
 int ViewPropertiesMenu::sortMode() const
 {
     return m_sortMode->checkedAction()->data().toInt();
