@@ -20,6 +20,8 @@
 
 #include "DeviceAutomounterKCM.h"
 
+#include <QDBusConnection>
+#include <QDBusMessage>
 #include <QStandardItem>
 #include <QStandardItemModel>
 #include <QItemSelectionModel>
@@ -36,19 +38,18 @@
 #include "DeviceModel.h"
 
 K_PLUGIN_FACTORY(DeviceAutomounterKCMFactory, registerPlugin<DeviceAutomounterKCM>();)
-K_EXPORT_PLUGIN(DeviceAutomounterKCMFactory("kcm_device_automounter"))
 
 DeviceAutomounterKCM::DeviceAutomounterKCM(QWidget *parent, const QVariantList &args)
     : KCModule(parent, args)//DeviceAutomounterKCMFactory::componentData(), parent)
 {
-    KAboutData *about = new KAboutData("kcm_device_automounter",
+    KAboutData *about = new KAboutData(QStringLiteral("kcm_device_automounter"),
                                        i18n("Device Automounter"),
-                                       "2.0",
+                                       QStringLiteral("2.0"),
                                        QString(),
                                        KAboutLicense::GPL_V2,
                                        i18n("(c) 2009 Trever Fischer, (c) 2015 Kai Uwe Broulik"));
     about->addAuthor(i18n("Trever Fischer"), i18n("Original Author"));
-    about->addAuthor(i18n("Kai Uwe Broulik"), i18n("Plasma 5 Port"), "kde@privat.broulik.de");
+    about->addAuthor(i18n("Kai Uwe Broulik"), i18n("Plasma 5 Port"), QStringLiteral("kde@privat.broulik.de"));
 
     setAboutData(about);
     setupUi(this);
@@ -129,7 +130,8 @@ void DeviceAutomounterKCM::save()
 {
     saveLayout();
 
-    AutomounterSettings::setAutomountEnabled(automountEnabled->isChecked());
+    const bool enabled = automountEnabled->isChecked();
+    AutomounterSettings::setAutomountEnabled(enabled);
     AutomounterSettings::setAutomountUnknownDevices(automountUnknownDevices->isChecked());
     AutomounterSettings::setAutomountOnLogin(automountOnLogin->isChecked());
     AutomounterSettings::setAutomountOnPlugin(automountOnPlugin->isChecked());
@@ -166,6 +168,23 @@ void DeviceAutomounterKCM::save()
     }
 
     AutomounterSettings::self()->save();
+
+    // Now tell kded to automatically load the module if loaded
+    QDBusConnection dbus = QDBusConnection::sessionBus();
+    QDBusMessage msg = QDBusMessage::createMethodCall(QStringLiteral("org.kde.kded5"),
+                                                      QStringLiteral("/kded"),
+                                                      QStringLiteral("org.kde.kded5"),
+                                                      QStringLiteral("setModuleAutoloading"));
+    msg.setArguments({QVariant(QStringLiteral("device_automounter")), QVariant(enabled)});
+    dbus.call(msg, QDBus::NoBlock);
+
+    // Load or unload right away
+    msg = QDBusMessage::createMethodCall(QStringLiteral("org.kde.kded5"),
+                                         QStringLiteral("/kded"),
+                                         QStringLiteral("org.kde.kded5"),
+                                         enabled ? QStringLiteral("loadModule") : QStringLiteral("unloadModule"));
+    msg.setArguments({QVariant(QStringLiteral("device_automounter"))});
+    dbus.call(msg, QDBus::NoBlock);
 }
 
 void DeviceAutomounterKCM::saveLayout()
